==> UIAPlatform-999.0.0-20220525.153239-26-sources.jar: com/sun/glass/ui/uia/provider/ItemContainerProviderAdapter.java <==
/*
 * -----------------------------------------------------------------
 * Copyright (c) 2021 BestSolution.at EDV Systemhaus GmbH
 * All Rights Reserved.
 *
 * BestSolution.at MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE  OR NON - INFRINGEMENT.
 * BestSolution.at SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY
 * LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS
 * SOFTWARE OR ITS DERIVATIVES.
 *
 * This software is released under the terms of the
 *
 *                  "GNU General Public License, Version 2 
 *                         with classpath exception"
 *
 * and may only be distributed and used under the terms of the
 * mentioned license. You should have received a copy of the license
 * along with this software product, if not you can download it from
 * http://www.gnu.org/licenses/gpl.html
 * ----------------------------------------------------------------
 */
package com.sun.glass.ui.uia.provider;

import com.sun.glass.ui.uia.ProxyAccessible;

import javafx.uia.IItemContainerProvider;

public class ItemContainerProviderAdapter extends BaseAdapter<IItemContainerProvider> implements NativeIItemContainerProvider {

    public ItemContainerProviderAdapter(ProxyAccessible accessible, IItemContainerProvider provider) {
        super(accessible, provider);
    }

    @Override
    public long FindItemByProperty(long pStartAfter, int propertyId, long pVariant) {
       
        // TODO map pointer to IUIAElement

        // TODO map variant

        //provider.FindItemByProperty(startAfter, propertyId, value)

        return 0;
    }

}

==> UIAPlatform-999.0.0-20231031.104843-44-sources.jar: com/sun/glass/ui/uia/provider/ItemContainerProviderAdapter.java <==
/*
 * -----------------------------------------------------------------
 * Copyright (c) 2021 BestSolution.at EDV Systemhaus GmbH
 * All Rights Reserved.
 *
 * BestSolution.at MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE  OR NON - INFRINGEMENT.
 * BestSolution.at SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY
 * LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS
 * SOFTWARE OR ITS DERIVATIVES.
 *
 * This software is released under the terms of the
 *
 *                  "GNU General Public License, Version 2 
 *                         with classpath exception"
 *
 * and may only be distributed and used under the terms of the
 * mentioned license. You should have received a copy of the license
 * along with this software product, if not you can download it from
 * http://www.gnu.org/licenses/gpl.html
 * ----------------------------------------------------------------
 */
package com.sun.glass.ui.uia.provider;

import com.sun.glass.ui.uia.ProxyAccessible;
import com.sun.glass.ui.uia.ProxyAccessibleRegistry;

import javafx.uia.IItemContainerProvider;
import javafx.uia.IPropertyId;
import javafx.uia.IUIAElement;
import javafx.uia.Variant;


public class ItemContainerProviderAdapter extends BaseAdapter<IItemContainerProvider> implements NativeIItemContainerProvider {

    public ItemContainerProviderAdapter(ProxyAccessible accessible, IItemContainerProvider provider) {
        super(accessible, provider);
    }

    @Override
    public long FindItemByProperty(long pStartAfter, int propertyId, long pVariant) {
      // map pointer to IUIAElement
      ProxyAccessible acc = ProxyAccessibleRegistry.getInstance().getByNative(pStartAfter);
      IUIAElement startAfter = acc.getUIAElement();
      // map propertyId
      IPropertyId propId = IPropertyId.fromNativeValue(propertyId);

      // map variant
      Variant variant = Variant.fromNativePointer(pVariant);

      IUIAElement result = provider.FindItemByProperty(startAfter, propId, variant);

      ProxyAccessible res = ProxyAccessibleRegistry.getInstance().findAccessible(result);
      return res.getNativeAccessible();
    }

    
}
